@@ -98,6 +98,19 @@ step1_sample_mvt <- function (data, y, .time, K = NULL, C = NULL, validation = N
     dat <- dat[dat$validation == "Fit",]
   }
 
+  if(is.null(parms)){
+    sorted_data <- dat[order(dat$time), ]
+
+    min_time <- min(sorted_data$time)
+
+    if (sum(sorted_data$time == min_time) > 3) {
+      selected_rows <- sorted_data$time == min_time
+    } else {
+      selected_rows <- seq_len(min(3, nrow(sorted_data)))
+    }
+    c0_initial <- mean(sorted_data$y[selected_rows])
+  }
+
   if(reparameterisation & zero_order){ # reparameterisation and k3 is 0
     MyFctNL = function(parms) { # Make function
       k1 = parms$k1
@@ -117,7 +130,7 @@ step1_sample_mvt <- function (data, y, .time, K = NULL, C = NULL, validation = N
     else {
       repeat {
         parms = list(k1 = stats::runif(1, 0, 40), k2 = stats::runif(1,
-                                                                    1000, 20000), c0 = mean(dat$y[dat$time == 0]))
+                                                                    1000, 20000), c0 = c0_initial)
         fit = suppressWarnings(minpack.lm::nls.lm(par = parms,
                                                   fn = MyFctNL, lower = rep(0, length(parms))))
         res = tryCatch({
@@ -170,7 +183,7 @@ step1_sample_mvt <- function (data, y, .time, K = NULL, C = NULL, validation = N
     else {
       repeat {
         parms = list(k1 = stats::runif(1, 0, 40), k2 = stats::runif(1,
-                                                                    1000, 20000), c0 = mean(dat$y[dat$time == 0]))
+                                                                    1000, 20000), c0 = c0_initial)
         fit = suppressWarnings(minpack.lm::nls.lm(par = parms,
                                                   fn = MyFctNL, lower = rep(0, length(parms))))
         res = tryCatch({
@@ -219,7 +232,7 @@ step1_sample_mvt <- function (data, y, .time, K = NULL, C = NULL, validation = N
     else {
       repeat {
         parms = list(k1 = stats::runif(1, 0, 60), k2 = stats::runif(1,
-                                                                    1000, 20000), k3 = stats::runif(1, 0, 11), c0 = mean(dat$y[dat$time == 0]))
+                                                                    1000, 20000), k3 = stats::runif(1, 0, 11), c0 = c0_initial)
         fit = suppressWarnings(minpack.lm::nls.lm(par = parms,
                                                   fn = MyFctNL, lower = rep(0, length(parms))))
         res = tryCatch({
@@ -272,7 +285,7 @@ step1_sample_mvt <- function (data, y, .time, K = NULL, C = NULL, validation = N
     else {
       repeat {
         parms = list(k1 = stats::runif(1, 0, 60), k2 = stats::runif(1,
-                                                                    1000, 20000), k3 = stats::runif(1, 0, 11), c0 = mean(dat$y[dat$time == 0]))
+                                                                    1000, 20000), k3 = stats::runif(1, 0, 11), c0 = c0_initial)
         fit = suppressWarnings(minpack.lm::nls.lm(par = parms,
                                                   fn = MyFctNL, lower = rep(0, length(parms))))
         res = tryCatch({
